# **Jtyoui** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 这是一个Python模块集合
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.7-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/项目-jtyoui-black.svg)]()


### 安装
    pip install jtyoui

### 网站
>>> [作者的网站](https://blog.jtyoui.com)

### 作者的邮箱
>>> jtyoui@qq.com  

### 命令行运行:打开控制台
    jtyoui -h # 获取帮助


***
[1]: https://blog.jtyoui.com